# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon WorkSpaces"
prefix = "workspaces"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateConnectionAlias = Action("AssociateConnectionAlias")
AssociateIpGroups = Action("AssociateIpGroups")
AuthorizeIpRules = Action("AuthorizeIpRules")
CopyWorkspaceImage = Action("CopyWorkspaceImage")
CreateConnectClientAddIn = Action("CreateConnectClientAddIn")
CreateConnectionAlias = Action("CreateConnectionAlias")
CreateIpGroup = Action("CreateIpGroup")
CreateTags = Action("CreateTags")
CreateUpdatedWorkspaceImage = Action("CreateUpdatedWorkspaceImage")
CreateWorkspaceBundle = Action("CreateWorkspaceBundle")
CreateWorkspaces = Action("CreateWorkspaces")
DeleteClientBranding = Action("DeleteClientBranding")
DeleteConnectClientAddIn = Action("DeleteConnectClientAddIn")
DeleteConnectionAlias = Action("DeleteConnectionAlias")
DeleteIpGroup = Action("DeleteIpGroup")
DeleteTags = Action("DeleteTags")
DeleteWorkspaceBundle = Action("DeleteWorkspaceBundle")
DeleteWorkspaceImage = Action("DeleteWorkspaceImage")
DeregisterWorkspaceDirectory = Action("DeregisterWorkspaceDirectory")
DescribeAccount = Action("DescribeAccount")
DescribeAccountModifications = Action("DescribeAccountModifications")
DescribeClientBranding = Action("DescribeClientBranding")
DescribeClientProperties = Action("DescribeClientProperties")
DescribeConnectClientAddIns = Action("DescribeConnectClientAddIns")
DescribeConnectionAliasPermissions = Action("DescribeConnectionAliasPermissions")
DescribeConnectionAliases = Action("DescribeConnectionAliases")
DescribeIpGroups = Action("DescribeIpGroups")
DescribeTags = Action("DescribeTags")
DescribeWorkspaceBundles = Action("DescribeWorkspaceBundles")
DescribeWorkspaceDirectories = Action("DescribeWorkspaceDirectories")
DescribeWorkspaceImagePermissions = Action("DescribeWorkspaceImagePermissions")
DescribeWorkspaceImages = Action("DescribeWorkspaceImages")
DescribeWorkspaceSnapshots = Action("DescribeWorkspaceSnapshots")
DescribeWorkspaces = Action("DescribeWorkspaces")
DescribeWorkspacesConnectionStatus = Action("DescribeWorkspacesConnectionStatus")
DisassociateConnectionAlias = Action("DisassociateConnectionAlias")
DisassociateIpGroups = Action("DisassociateIpGroups")
ImportClientBranding = Action("ImportClientBranding")
ImportWorkspaceImage = Action("ImportWorkspaceImage")
ListAvailableManagementCidrRanges = Action("ListAvailableManagementCidrRanges")
MigrateWorkspace = Action("MigrateWorkspace")
ModifyAccount = Action("ModifyAccount")
ModifyClientProperties = Action("ModifyClientProperties")
ModifySelfservicePermissions = Action("ModifySelfservicePermissions")
ModifyWorkspaceAccessProperties = Action("ModifyWorkspaceAccessProperties")
ModifyWorkspaceCreationProperties = Action("ModifyWorkspaceCreationProperties")
ModifyWorkspaceProperties = Action("ModifyWorkspaceProperties")
ModifyWorkspaceState = Action("ModifyWorkspaceState")
RebootWorkspaces = Action("RebootWorkspaces")
RebuildWorkspaces = Action("RebuildWorkspaces")
RegisterWorkspaceDirectory = Action("RegisterWorkspaceDirectory")
RestoreWorkspace = Action("RestoreWorkspace")
RevokeIpRules = Action("RevokeIpRules")
StartWorkspaces = Action("StartWorkspaces")
StopWorkspaces = Action("StopWorkspaces")
TerminateWorkspaces = Action("TerminateWorkspaces")
UpdateConnectClientAddIn = Action("UpdateConnectClientAddIn")
UpdateConnectionAliasPermission = Action("UpdateConnectionAliasPermission")
UpdateRulesOfIpGroup = Action("UpdateRulesOfIpGroup")
UpdateWorkspaceBundle = Action("UpdateWorkspaceBundle")
UpdateWorkspaceImagePermission = Action("UpdateWorkspaceImagePermission")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodeArtifact"
prefix = "codeartifact"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateExternalConnection = Action("AssociateExternalConnection")
AssociateWithDownstreamRepository = Action("AssociateWithDownstreamRepository")
CopyPackageVersions = Action("CopyPackageVersions")
CreateDomain = Action("CreateDomain")
CreateRepository = Action("CreateRepository")
DeleteDomain = Action("DeleteDomain")
DeleteDomainPermissionsPolicy = Action("DeleteDomainPermissionsPolicy")
DeletePackageVersions = Action("DeletePackageVersions")
DeleteRepository = Action("DeleteRepository")
DeleteRepositoryPermissionsPolicy = Action("DeleteRepositoryPermissionsPolicy")
DescribeDomain = Action("DescribeDomain")
DescribePackage = Action("DescribePackage")
DescribePackageVersion = Action("DescribePackageVersion")
DescribeRepository = Action("DescribeRepository")
DisassociateExternalConnection = Action("DisassociateExternalConnection")
DisposePackageVersions = Action("DisposePackageVersions")
GetAuthorizationToken = Action("GetAuthorizationToken")
GetDomainPermissionsPolicy = Action("GetDomainPermissionsPolicy")
GetPackageVersionAsset = Action("GetPackageVersionAsset")
GetPackageVersionReadme = Action("GetPackageVersionReadme")
GetRepositoryEndpoint = Action("GetRepositoryEndpoint")
GetRepositoryPermissionsPolicy = Action("GetRepositoryPermissionsPolicy")
ListDomains = Action("ListDomains")
ListPackageVersionAssets = Action("ListPackageVersionAssets")
ListPackageVersionDependencies = Action("ListPackageVersionDependencies")
ListPackageVersions = Action("ListPackageVersions")
ListPackages = Action("ListPackages")
ListRepositories = Action("ListRepositories")
ListRepositoriesInDomain = Action("ListRepositoriesInDomain")
ListTagsForResource = Action("ListTagsForResource")
PublishPackageVersion = Action("PublishPackageVersion")
PutDomainPermissionsPolicy = Action("PutDomainPermissionsPolicy")
PutPackageMetadata = Action("PutPackageMetadata")
PutPackageOriginConfiguration = Action("PutPackageOriginConfiguration")
PutRepositoryPermissionsPolicy = Action("PutRepositoryPermissionsPolicy")
ReadFromRepository = Action("ReadFromRepository")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdatePackageVersionsStatus = Action("UpdatePackageVersionsStatus")
UpdateRepository = Action("UpdateRepository")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Kinesis Video Streams"
prefix = "kinesisvideo"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ConnectAsMaster = Action("ConnectAsMaster")
ConnectAsViewer = Action("ConnectAsViewer")
CreateSignalingChannel = Action("CreateSignalingChannel")
CreateStream = Action("CreateStream")
DeleteSignalingChannel = Action("DeleteSignalingChannel")
DeleteStream = Action("DeleteStream")
DescribeImageGenerationConfiguration = Action("DescribeImageGenerationConfiguration")
DescribeNotificationConfiguration = Action("DescribeNotificationConfiguration")
DescribeSignalingChannel = Action("DescribeSignalingChannel")
DescribeStream = Action("DescribeStream")
GetClip = Action("GetClip")
GetDASHStreamingSessionURL = Action("GetDASHStreamingSessionURL")
GetDataEndpoint = Action("GetDataEndpoint")
GetHLSStreamingSessionURL = Action("GetHLSStreamingSessionURL")
GetIceServerConfig = Action("GetIceServerConfig")
GetImages = Action("GetImages")
GetMedia = Action("GetMedia")
GetMediaForFragmentList = Action("GetMediaForFragmentList")
GetSignalingChannelEndpoint = Action("GetSignalingChannelEndpoint")
ListFragments = Action("ListFragments")
ListSignalingChannels = Action("ListSignalingChannels")
ListStreams = Action("ListStreams")
ListTagsForResource = Action("ListTagsForResource")
ListTagsForStream = Action("ListTagsForStream")
PutMedia = Action("PutMedia")
SendAlexaOfferToMaster = Action("SendAlexaOfferToMaster")
TagResource = Action("TagResource")
TagStream = Action("TagStream")
UntagResource = Action("UntagResource")
UntagStream = Action("UntagStream")
UpdateDataRetention = Action("UpdateDataRetention")
UpdateImageGenerationConfiguration = Action("UpdateImageGenerationConfiguration")
UpdateNotificationConfiguration = Action("UpdateNotificationConfiguration")
UpdateSignalingChannel = Action("UpdateSignalingChannel")
UpdateStream = Action("UpdateStream")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Backup Gateway"
prefix = "backup-gateway"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateGatewayToServer = Action("AssociateGatewayToServer")
Backup = Action("Backup")
CreateGateway = Action("CreateGateway")
DeleteGateway = Action("DeleteGateway")
DeleteHypervisor = Action("DeleteHypervisor")
DisassociateGatewayFromServer = Action("DisassociateGatewayFromServer")
GetGateway = Action("GetGateway")
ImportHypervisorConfiguration = Action("ImportHypervisorConfiguration")
ListGateways = Action("ListGateways")
ListHypervisors = Action("ListHypervisors")
ListTagsForResource = Action("ListTagsForResource")
ListVirtualMachines = Action("ListVirtualMachines")
PutMaintenanceStartTime = Action("PutMaintenanceStartTime")
Restore = Action("Restore")
TagResource = Action("TagResource")
TestHypervisorConfiguration = Action("TestHypervisorConfiguration")
UntagResource = Action("UntagResource")
UpdateGatewayInformation = Action("UpdateGatewayInformation")
UpdateGatewaySoftwareNow = Action("UpdateGatewaySoftwareNow")
UpdateHypervisor = Action("UpdateHypervisor")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "CloudWatch Application Insights"
prefix = "applicationinsights"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApplication = Action("CreateApplication")
CreateComponent = Action("CreateComponent")
CreateLogPattern = Action("CreateLogPattern")
DeleteApplication = Action("DeleteApplication")
DeleteComponent = Action("DeleteComponent")
DeleteLogPattern = Action("DeleteLogPattern")
DescribeApplication = Action("DescribeApplication")
DescribeComponent = Action("DescribeComponent")
DescribeComponentConfiguration = Action("DescribeComponentConfiguration")
DescribeComponentConfigurationRecommendation = Action(
    "DescribeComponentConfigurationRecommendation"
)
DescribeLogPattern = Action("DescribeLogPattern")
DescribeObservation = Action("DescribeObservation")
DescribeProblem = Action("DescribeProblem")
DescribeProblemObservations = Action("DescribeProblemObservations")
ListApplications = Action("ListApplications")
ListComponents = Action("ListComponents")
ListConfigurationHistory = Action("ListConfigurationHistory")
ListLogPatternSets = Action("ListLogPatternSets")
ListLogPatterns = Action("ListLogPatterns")
ListProblems = Action("ListProblems")
ListTagsForResource = Action("ListTagsForResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApplication = Action("UpdateApplication")
UpdateComponent = Action("UpdateComponent")
UpdateComponentConfiguration = Action("UpdateComponentConfiguration")
UpdateLogPattern = Action("UpdateLogPattern")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Timestream"
prefix = "timestream"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelQuery = Action("CancelQuery")
CreateDatabase = Action("CreateDatabase")
CreateScheduledQuery = Action("CreateScheduledQuery")
CreateTable = Action("CreateTable")
DeleteDatabase = Action("DeleteDatabase")
DeleteScheduledQuery = Action("DeleteScheduledQuery")
DeleteTable = Action("DeleteTable")
DescribeDatabase = Action("DescribeDatabase")
DescribeEndpoints = Action("DescribeEndpoints")
DescribeScheduledQuery = Action("DescribeScheduledQuery")
DescribeTable = Action("DescribeTable")
ExecuteScheduledQuery = Action("ExecuteScheduledQuery")
ListDatabases = Action("ListDatabases")
ListMeasures = Action("ListMeasures")
ListScheduledQueries = Action("ListScheduledQueries")
ListTables = Action("ListTables")
ListTagsForResource = Action("ListTagsForResource")
PrepareQuery = Action("PrepareQuery")
Select = Action("Select")
SelectValues = Action("SelectValues")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDatabase = Action("UpdateDatabase")
UpdateScheduledQuery = Action("UpdateScheduledQuery")
UpdateTable = Action("UpdateTable")
WriteRecords = Action("WriteRecords")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS WAF V2"
prefix = "wafv2"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateWebACL = Action("AssociateWebACL")
CheckCapacity = Action("CheckCapacity")
CreateIPSet = Action("CreateIPSet")
CreateRegexPatternSet = Action("CreateRegexPatternSet")
CreateRuleGroup = Action("CreateRuleGroup")
CreateWebACL = Action("CreateWebACL")
DeleteFirewallManagerRuleGroups = Action("DeleteFirewallManagerRuleGroups")
DeleteIPSet = Action("DeleteIPSet")
DeleteLoggingConfiguration = Action("DeleteLoggingConfiguration")
DeletePermissionPolicy = Action("DeletePermissionPolicy")
DeleteRegexPatternSet = Action("DeleteRegexPatternSet")
DeleteRuleGroup = Action("DeleteRuleGroup")
DeleteWebACL = Action("DeleteWebACL")
DescribeManagedRuleGroup = Action("DescribeManagedRuleGroup")
DisassociateFirewallManager = Action("DisassociateFirewallManager")
DisassociateWebACL = Action("DisassociateWebACL")
GenerateMobileSdkReleaseUrl = Action("GenerateMobileSdkReleaseUrl")
GetIPSet = Action("GetIPSet")
GetLoggingConfiguration = Action("GetLoggingConfiguration")
GetManagedRuleSet = Action("GetManagedRuleSet")
GetMobileSdkRelease = Action("GetMobileSdkRelease")
GetPermissionPolicy = Action("GetPermissionPolicy")
GetRateBasedStatementManagedKeys = Action("GetRateBasedStatementManagedKeys")
GetRegexPatternSet = Action("GetRegexPatternSet")
GetRuleGroup = Action("GetRuleGroup")
GetSampledRequests = Action("GetSampledRequests")
GetWebACL = Action("GetWebACL")
GetWebACLForResource = Action("GetWebACLForResource")
ListAvailableManagedRuleGroupVersions = Action("ListAvailableManagedRuleGroupVersions")
ListAvailableManagedRuleGroups = Action("ListAvailableManagedRuleGroups")
ListIPSets = Action("ListIPSets")
ListLoggingConfigurations = Action("ListLoggingConfigurations")
ListManagedRuleSets = Action("ListManagedRuleSets")
ListMobileSdkReleases = Action("ListMobileSdkReleases")
ListRegexPatternSets = Action("ListRegexPatternSets")
ListResourcesForWebACL = Action("ListResourcesForWebACL")
ListRuleGroups = Action("ListRuleGroups")
ListTagsForResource = Action("ListTagsForResource")
ListWebACLs = Action("ListWebACLs")
PutFirewallManagerRuleGroups = Action("PutFirewallManagerRuleGroups")
PutLoggingConfiguration = Action("PutLoggingConfiguration")
PutManagedRuleSetVersions = Action("PutManagedRuleSetVersions")
PutPermissionPolicy = Action("PutPermissionPolicy")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateIPSet = Action("UpdateIPSet")
UpdateManagedRuleSetVersionExpiryDate = Action("UpdateManagedRuleSetVersionExpiryDate")
UpdateRegexPatternSet = Action("UpdateRegexPatternSet")
UpdateRuleGroup = Action("UpdateRuleGroup")
UpdateWebACL = Action("UpdateWebACL")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Translate"
prefix = "translate"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateParallelData = Action("CreateParallelData")
DeleteParallelData = Action("DeleteParallelData")
DeleteTerminology = Action("DeleteTerminology")
DescribeTextTranslationJob = Action("DescribeTextTranslationJob")
GetParallelData = Action("GetParallelData")
GetTerminology = Action("GetTerminology")
ImportTerminology = Action("ImportTerminology")
ListParallelData = Action("ListParallelData")
ListTerminologies = Action("ListTerminologies")
ListTextTranslationJobs = Action("ListTextTranslationJobs")
StartTextTranslationJob = Action("StartTextTranslationJob")
StopTextTranslationJob = Action("StopTextTranslationJob")
TranslateText = Action("TranslateText")
UpdateParallelData = Action("UpdateParallelData")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon ElastiCache"
prefix = "elasticache"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTagsToResource = Action("AddTagsToResource")
AuthorizeCacheSecurityGroupIngress = Action("AuthorizeCacheSecurityGroupIngress")
BatchApplyUpdateAction = Action("BatchApplyUpdateAction")
BatchStopUpdateAction = Action("BatchStopUpdateAction")
CompleteMigration = Action("CompleteMigration")
CopySnapshot = Action("CopySnapshot")
CreateCacheCluster = Action("CreateCacheCluster")
CreateCacheParameterGroup = Action("CreateCacheParameterGroup")
CreateCacheSecurityGroup = Action("CreateCacheSecurityGroup")
CreateCacheSubnetGroup = Action("CreateCacheSubnetGroup")
CreateGlobalReplicationGroup = Action("CreateGlobalReplicationGroup")
CreateReplicationGroup = Action("CreateReplicationGroup")
CreateSnapshot = Action("CreateSnapshot")
CreateUser = Action("CreateUser")
CreateUserGroup = Action("CreateUserGroup")
DecreaseNodeGroupsInGlobalReplicationGroup = Action(
    "DecreaseNodeGroupsInGlobalReplicationGroup"
)
DecreaseReplicaCount = Action("DecreaseReplicaCount")
DeleteCacheCluster = Action("DeleteCacheCluster")
DeleteCacheParameterGroup = Action("DeleteCacheParameterGroup")
DeleteCacheSecurityGroup = Action("DeleteCacheSecurityGroup")
DeleteCacheSubnetGroup = Action("DeleteCacheSubnetGroup")
DeleteGlobalReplicationGroup = Action("DeleteGlobalReplicationGroup")
DeleteReplicationGroup = Action("DeleteReplicationGroup")
DeleteSnapshot = Action("DeleteSnapshot")
DeleteUser = Action("DeleteUser")
DeleteUserGroup = Action("DeleteUserGroup")
DescribeCacheClusters = Action("DescribeCacheClusters")
DescribeCacheEngineVersions = Action("DescribeCacheEngineVersions")
DescribeCacheParameterGroups = Action("DescribeCacheParameterGroups")
DescribeCacheParameters = Action("DescribeCacheParameters")
DescribeCacheSecurityGroups = Action("DescribeCacheSecurityGroups")
DescribeCacheSubnetGroups = Action("DescribeCacheSubnetGroups")
DescribeEngineDefaultParameters = Action("DescribeEngineDefaultParameters")
DescribeEvents = Action("DescribeEvents")
DescribeGlobalReplicationGroups = Action("DescribeGlobalReplicationGroups")
DescribeReplicationGroups = Action("DescribeReplicationGroups")
DescribeReservedCacheNodes = Action("DescribeReservedCacheNodes")
DescribeReservedCacheNodesOfferings = Action("DescribeReservedCacheNodesOfferings")
DescribeServiceUpdates = Action("DescribeServiceUpdates")
DescribeSnapshots = Action("DescribeSnapshots")
DescribeUpdateActions = Action("DescribeUpdateActions")
DescribeUserGroups = Action("DescribeUserGroups")
DescribeUsers = Action("DescribeUsers")
DisassociateGlobalReplicationGroup = Action("DisassociateGlobalReplicationGroup")
FailoverGlobalReplicationGroup = Action("FailoverGlobalReplicationGroup")
IncreaseNodeGroupsInGlobalReplicationGroup = Action(
    "IncreaseNodeGroupsInGlobalReplicationGroup"
)
IncreaseReplicaCount = Action("IncreaseReplicaCount")
ListAllowedNodeTypeModifications = Action("ListAllowedNodeTypeModifications")
ListTagsForResource = Action("ListTagsForResource")
ModifyCacheCluster = Action("ModifyCacheCluster")
ModifyCacheParameterGroup = Action("ModifyCacheParameterGroup")
ModifyCacheSubnetGroup = Action("ModifyCacheSubnetGroup")
ModifyGlobalReplicationGroup = Action("ModifyGlobalReplicationGroup")
ModifyReplicationGroup = Action("ModifyReplicationGroup")
ModifyReplicationGroupShardConfiguration = Action(
    "ModifyReplicationGroupShardConfiguration"
)
ModifyUser = Action("ModifyUser")
ModifyUserGroup = Action("ModifyUserGroup")
PurchaseReservedCacheNodesOffering = Action("PurchaseReservedCacheNodesOffering")
RebalanceSlotsInGlobalReplicationGroup = Action(
    "RebalanceSlotsInGlobalReplicationGroup"
)
RebootCacheCluster = Action("RebootCacheCluster")
RemoveTagsFromResource = Action("RemoveTagsFromResource")
ResetCacheParameterGroup = Action("ResetCacheParameterGroup")
RevokeCacheSecurityGroupIngress = Action("RevokeCacheSecurityGroupIngress")
StartMigration = Action("StartMigration")
TestFailover = Action("TestFailover")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Route 53 Resolver"
prefix = "route53resolver"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateFirewallRuleGroup = Action("AssociateFirewallRuleGroup")
AssociateResolverEndpointIpAddress = Action("AssociateResolverEndpointIpAddress")
AssociateResolverQueryLogConfig = Action("AssociateResolverQueryLogConfig")
AssociateResolverRule = Action("AssociateResolverRule")
CreateFirewallDomainList = Action("CreateFirewallDomainList")
CreateFirewallRule = Action("CreateFirewallRule")
CreateFirewallRuleGroup = Action("CreateFirewallRuleGroup")
CreateResolverEndpoint = Action("CreateResolverEndpoint")
CreateResolverQueryLogConfig = Action("CreateResolverQueryLogConfig")
CreateResolverRule = Action("CreateResolverRule")
DeleteFirewallDomainList = Action("DeleteFirewallDomainList")
DeleteFirewallRule = Action("DeleteFirewallRule")
DeleteFirewallRuleGroup = Action("DeleteFirewallRuleGroup")
DeleteResolverEndpoint = Action("DeleteResolverEndpoint")
DeleteResolverQueryLogConfig = Action("DeleteResolverQueryLogConfig")
DeleteResolverRule = Action("DeleteResolverRule")
DisassociateFirewallRuleGroup = Action("DisassociateFirewallRuleGroup")
DisassociateResolverEndpointIpAddress = Action("DisassociateResolverEndpointIpAddress")
DisassociateResolverQueryLogConfig = Action("DisassociateResolverQueryLogConfig")
DisassociateResolverRule = Action("DisassociateResolverRule")
GetFirewallConfig = Action("GetFirewallConfig")
GetFirewallDomainList = Action("GetFirewallDomainList")
GetFirewallRuleGroup = Action("GetFirewallRuleGroup")
GetFirewallRuleGroupAssociation = Action("GetFirewallRuleGroupAssociation")
GetFirewallRuleGroupPolicy = Action("GetFirewallRuleGroupPolicy")
GetResolverConfig = Action("GetResolverConfig")
GetResolverDnssecConfig = Action("GetResolverDnssecConfig")
GetResolverEndpoint = Action("GetResolverEndpoint")
GetResolverQueryLogConfig = Action("GetResolverQueryLogConfig")
GetResolverQueryLogConfigAssociation = Action("GetResolverQueryLogConfigAssociation")
GetResolverQueryLogConfigPolicy = Action("GetResolverQueryLogConfigPolicy")
GetResolverRule = Action("GetResolverRule")
GetResolverRuleAssociation = Action("GetResolverRuleAssociation")
GetResolverRulePolicy = Action("GetResolverRulePolicy")
ImportFirewallDomains = Action("ImportFirewallDomains")
ListFirewallConfigs = Action("ListFirewallConfigs")
ListFirewallDomainLists = Action("ListFirewallDomainLists")
ListFirewallDomains = Action("ListFirewallDomains")
ListFirewallRuleGroupAssociations = Action("ListFirewallRuleGroupAssociations")
ListFirewallRuleGroups = Action("ListFirewallRuleGroups")
ListFirewallRules = Action("ListFirewallRules")
ListResolverConfigs = Action("ListResolverConfigs")
ListResolverDnssecConfigs = Action("ListResolverDnssecConfigs")
ListResolverEndpointIpAddresses = Action("ListResolverEndpointIpAddresses")
ListResolverEndpoints = Action("ListResolverEndpoints")
ListResolverQueryLogConfigAssociations = Action(
    "ListResolverQueryLogConfigAssociations"
)
ListResolverQueryLogConfigs = Action("ListResolverQueryLogConfigs")
ListResolverRuleAssociations = Action("ListResolverRuleAssociations")
ListResolverRules = Action("ListResolverRules")
ListTagsForResource = Action("ListTagsForResource")
PutFirewallRuleGroupPolicy = Action("PutFirewallRuleGroupPolicy")
PutResolverQueryLogConfigPolicy = Action("PutResolverQueryLogConfigPolicy")
PutResolverRulePolicy = Action("PutResolverRulePolicy")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateFirewallConfig = Action("UpdateFirewallConfig")
UpdateFirewallDomains = Action("UpdateFirewallDomains")
UpdateFirewallRule = Action("UpdateFirewallRule")
UpdateFirewallRuleGroupAssociation = Action("UpdateFirewallRuleGroupAssociation")
UpdateResolverConfig = Action("UpdateResolverConfig")
UpdateResolverDnssecConfig = Action("UpdateResolverDnssecConfig")
UpdateResolverEndpoint = Action("UpdateResolverEndpoint")
UpdateResolverRule = Action("UpdateResolverRule")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Honeycode"
prefix = "honeycode"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ApproveTeamAssociation = Action("ApproveTeamAssociation")
BatchCreateTableRows = Action("BatchCreateTableRows")
BatchDeleteTableRows = Action("BatchDeleteTableRows")
BatchUpdateTableRows = Action("BatchUpdateTableRows")
BatchUpsertTableRows = Action("BatchUpsertTableRows")
CreateTeam = Action("CreateTeam")
CreateTenant = Action("CreateTenant")
DeleteDomains = Action("DeleteDomains")
DeregisterGroups = Action("DeregisterGroups")
DescribeTableDataImportJob = Action("DescribeTableDataImportJob")
DescribeTeam = Action("DescribeTeam")
GetScreenData = Action("GetScreenData")
InvokeScreenAutomation = Action("InvokeScreenAutomation")
ListDomains = Action("ListDomains")
ListGroups = Action("ListGroups")
ListTableColumns = Action("ListTableColumns")
ListTableRows = Action("ListTableRows")
ListTables = Action("ListTables")
ListTagsForResource = Action("ListTagsForResource")
ListTeamAssociations = Action("ListTeamAssociations")
ListTenants = Action("ListTenants")
QueryTableRows = Action("QueryTableRows")
RegisterDomainForVerification = Action("RegisterDomainForVerification")
RegisterGroups = Action("RegisterGroups")
RejectTeamAssociation = Action("RejectTeamAssociation")
RestartDomainVerification = Action("RestartDomainVerification")
StartTableDataImportJob = Action("StartTableDataImportJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateTeam = Action("UpdateTeam")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon GameLift"
prefix = "gamelift"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptMatch = Action("AcceptMatch")
ClaimGameServer = Action("ClaimGameServer")
CreateAlias = Action("CreateAlias")
CreateBuild = Action("CreateBuild")
CreateFleet = Action("CreateFleet")
CreateFleetLocations = Action("CreateFleetLocations")
CreateGameServerGroup = Action("CreateGameServerGroup")
CreateGameSession = Action("CreateGameSession")
CreateGameSessionQueue = Action("CreateGameSessionQueue")
CreateMatchmakingConfiguration = Action("CreateMatchmakingConfiguration")
CreateMatchmakingRuleSet = Action("CreateMatchmakingRuleSet")
CreatePlayerSession = Action("CreatePlayerSession")
CreatePlayerSessions = Action("CreatePlayerSessions")
CreateScript = Action("CreateScript")
CreateVpcPeeringAuthorization = Action("CreateVpcPeeringAuthorization")
CreateVpcPeeringConnection = Action("CreateVpcPeeringConnection")
DeleteAlias = Action("DeleteAlias")
DeleteBuild = Action("DeleteBuild")
DeleteFleet = Action("DeleteFleet")
DeleteFleetLocations = Action("DeleteFleetLocations")
DeleteGameServerGroup = Action("DeleteGameServerGroup")
DeleteGameSessionQueue = Action("DeleteGameSessionQueue")
DeleteMatchmakingConfiguration = Action("DeleteMatchmakingConfiguration")
DeleteMatchmakingRuleSet = Action("DeleteMatchmakingRuleSet")
DeleteScalingPolicy = Action("DeleteScalingPolicy")
DeleteScript = Action("DeleteScript")
DeleteVpcPeeringAuthorization = Action("DeleteVpcPeeringAuthorization")
DeleteVpcPeeringConnection = Action("DeleteVpcPeeringConnection")
DeregisterGameServer = Action("DeregisterGameServer")
DescribeAlias = Action("DescribeAlias")
DescribeBuild = Action("DescribeBuild")
DescribeEC2InstanceLimits = Action("DescribeEC2InstanceLimits")
DescribeFleetAttributes = Action("DescribeFleetAttributes")
DescribeFleetCapacity = Action("DescribeFleetCapacity")
DescribeFleetEvents = Action("DescribeFleetEvents")
DescribeFleetLocationAttributes = Action("DescribeFleetLocationAttributes")
DescribeFleetLocationCapacity = Action("DescribeFleetLocationCapacity")
DescribeFleetLocationUtilization = Action("DescribeFleetLocationUtilization")
DescribeFleetPortSettings = Action("DescribeFleetPortSettings")
DescribeFleetUtilization = Action("DescribeFleetUtilization")
DescribeGameServer = Action("DescribeGameServer")
DescribeGameServerGroup = Action("DescribeGameServerGroup")
DescribeGameServerInstances = Action("DescribeGameServerInstances")
DescribeGameSessionDetails = Action("DescribeGameSessionDetails")
DescribeGameSessionPlacement = Action("DescribeGameSessionPlacement")
DescribeGameSessionQueues = Action("DescribeGameSessionQueues")
DescribeGameSessions = Action("DescribeGameSessions")
DescribeInstances = Action("DescribeInstances")
DescribeMatchmaking = Action("DescribeMatchmaking")
DescribeMatchmakingConfigurations = Action("DescribeMatchmakingConfigurations")
DescribeMatchmakingRuleSets = Action("DescribeMatchmakingRuleSets")
DescribePlayerSessions = Action("DescribePlayerSessions")
DescribeRuntimeConfiguration = Action("DescribeRuntimeConfiguration")
DescribeScalingPolicies = Action("DescribeScalingPolicies")
DescribeScript = Action("DescribeScript")
DescribeVpcPeeringAuthorizations = Action("DescribeVpcPeeringAuthorizations")
DescribeVpcPeeringConnections = Action("DescribeVpcPeeringConnections")
GetGameSessionLogUrl = Action("GetGameSessionLogUrl")
GetInstanceAccess = Action("GetInstanceAccess")
ListAliases = Action("ListAliases")
ListBuilds = Action("ListBuilds")
ListFleets = Action("ListFleets")
ListGameServerGroups = Action("ListGameServerGroups")
ListGameServers = Action("ListGameServers")
ListScripts = Action("ListScripts")
ListTagsForResource = Action("ListTagsForResource")
PutScalingPolicy = Action("PutScalingPolicy")
RegisterGameServer = Action("RegisterGameServer")
RequestUploadCredentials = Action("RequestUploadCredentials")
ResolveAlias = Action("ResolveAlias")
ResumeGameServerGroup = Action("ResumeGameServerGroup")
SearchGameSessions = Action("SearchGameSessions")
StartFleetActions = Action("StartFleetActions")
StartGameSessionPlacement = Action("StartGameSessionPlacement")
StartMatchBackfill = Action("StartMatchBackfill")
StartMatchmaking = Action("StartMatchmaking")
StopFleetActions = Action("StopFleetActions")
StopGameSessionPlacement = Action("StopGameSessionPlacement")
StopMatchmaking = Action("StopMatchmaking")
SuspendGameServerGroup = Action("SuspendGameServerGroup")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAlias = Action("UpdateAlias")
UpdateBuild = Action("UpdateBuild")
UpdateFleetAttributes = Action("UpdateFleetAttributes")
UpdateFleetCapacity = Action("UpdateFleetCapacity")
UpdateFleetPortSettings = Action("UpdateFleetPortSettings")
UpdateGameServer = Action("UpdateGameServer")
UpdateGameServerGroup = Action("UpdateGameServerGroup")
UpdateGameSession = Action("UpdateGameSession")
UpdateGameSessionQueue = Action("UpdateGameSessionQueue")
UpdateMatchmakingConfiguration = Action("UpdateMatchmakingConfiguration")
UpdateRuntimeConfiguration = Action("UpdateRuntimeConfiguration")
UpdateScript = Action("UpdateScript")
ValidateMatchmakingRuleSet = Action("ValidateMatchmakingRuleSet")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Step Functions"
prefix = "states"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateActivity = Action("CreateActivity")
CreateStateMachine = Action("CreateStateMachine")
DeleteActivity = Action("DeleteActivity")
DeleteStateMachine = Action("DeleteStateMachine")
DescribeActivity = Action("DescribeActivity")
DescribeExecution = Action("DescribeExecution")
DescribeStateMachine = Action("DescribeStateMachine")
DescribeStateMachineForExecution = Action("DescribeStateMachineForExecution")
GetActivityTask = Action("GetActivityTask")
GetExecutionHistory = Action("GetExecutionHistory")
ListActivities = Action("ListActivities")
ListExecutions = Action("ListExecutions")
ListStateMachines = Action("ListStateMachines")
ListTagsForResource = Action("ListTagsForResource")
SendTaskFailure = Action("SendTaskFailure")
SendTaskHeartbeat = Action("SendTaskHeartbeat")
SendTaskSuccess = Action("SendTaskSuccess")
StartExecution = Action("StartExecution")
StartSyncExecution = Action("StartSyncExecution")
StopExecution = Action("StopExecution")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateStateMachine = Action("UpdateStateMachine")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Route 53 Domains"
prefix = "route53domains"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptDomainTransferFromAnotherAwsAccount = Action(
    "AcceptDomainTransferFromAnotherAwsAccount"
)
CancelDomainTransferToAnotherAwsAccount = Action(
    "CancelDomainTransferToAnotherAwsAccount"
)
CheckDomainAvailability = Action("CheckDomainAvailability")
CheckDomainTransferability = Action("CheckDomainTransferability")
DeleteDomain = Action("DeleteDomain")
DeleteTagsForDomain = Action("DeleteTagsForDomain")
DisableDomainAutoRenew = Action("DisableDomainAutoRenew")
DisableDomainTransferLock = Action("DisableDomainTransferLock")
EnableDomainAutoRenew = Action("EnableDomainAutoRenew")
EnableDomainTransferLock = Action("EnableDomainTransferLock")
GetContactReachabilityStatus = Action("GetContactReachabilityStatus")
GetDomainDetail = Action("GetDomainDetail")
GetDomainSuggestions = Action("GetDomainSuggestions")
GetOperationDetail = Action("GetOperationDetail")
ListDomains = Action("ListDomains")
ListOperations = Action("ListOperations")
ListPrices = Action("ListPrices")
ListTagsForDomain = Action("ListTagsForDomain")
RegisterDomain = Action("RegisterDomain")
RejectDomainTransferFromAnotherAwsAccount = Action(
    "RejectDomainTransferFromAnotherAwsAccount"
)
RenewDomain = Action("RenewDomain")
ResendContactReachabilityEmail = Action("ResendContactReachabilityEmail")
RetrieveDomainAuthCode = Action("RetrieveDomainAuthCode")
TransferDomain = Action("TransferDomain")
TransferDomainToAnotherAwsAccount = Action("TransferDomainToAnotherAwsAccount")
UpdateDomainContact = Action("UpdateDomainContact")
UpdateDomainContactPrivacy = Action("UpdateDomainContactPrivacy")
UpdateDomainNameservers = Action("UpdateDomainNameservers")
UpdateTagsForDomain = Action("UpdateTagsForDomain")
ViewBilling = Action("ViewBilling")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT"
prefix = "iot"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptCertificateTransfer = Action("AcceptCertificateTransfer")
AddThingToBillingGroup = Action("AddThingToBillingGroup")
AddThingToThingGroup = Action("AddThingToThingGroup")
AssociateTargetsWithJob = Action("AssociateTargetsWithJob")
AttachPolicy = Action("AttachPolicy")
AttachPrincipalPolicy = Action("AttachPrincipalPolicy")
AttachSecurityProfile = Action("AttachSecurityProfile")
AttachThingPrincipal = Action("AttachThingPrincipal")
CancelAuditMitigationActionsTask = Action("CancelAuditMitigationActionsTask")
CancelAuditTask = Action("CancelAuditTask")
CancelCertificateTransfer = Action("CancelCertificateTransfer")
CancelDetectMitigationActionsTask = Action("CancelDetectMitigationActionsTask")
CancelJob = Action("CancelJob")
CancelJobExecution = Action("CancelJobExecution")
ClearDefaultAuthorizer = Action("ClearDefaultAuthorizer")
CloseTunnel = Action("CloseTunnel")
ConfirmTopicRuleDestination = Action("ConfirmTopicRuleDestination")
Connect = Action("Connect")
CreateAuditSuppression = Action("CreateAuditSuppression")
CreateAuthorizer = Action("CreateAuthorizer")
CreateBillingGroup = Action("CreateBillingGroup")
CreateCertificateFromCsr = Action("CreateCertificateFromCsr")
CreateCustomMetric = Action("CreateCustomMetric")
CreateDimension = Action("CreateDimension")
CreateDomainConfiguration = Action("CreateDomainConfiguration")
CreateDynamicThingGroup = Action("CreateDynamicThingGroup")
CreateFleetMetric = Action("CreateFleetMetric")
CreateJob = Action("CreateJob")
CreateJobTemplate = Action("CreateJobTemplate")
CreateKeysAndCertificate = Action("CreateKeysAndCertificate")
CreateMitigationAction = Action("CreateMitigationAction")
CreateOTAUpdate = Action("CreateOTAUpdate")
CreateOTAUpdateJob = Action("CreateOTAUpdateJob")
CreatePolicy = Action("CreatePolicy")
CreatePolicyVersion = Action("CreatePolicyVersion")
CreateProvisioningClaim = Action("CreateProvisioningClaim")
CreateProvisioningTemplate = Action("CreateProvisioningTemplate")
CreateProvisioningTemplateVersion = Action("CreateProvisioningTemplateVersion")
CreateRoleAlias = Action("CreateRoleAlias")
CreateScheduledAudit = Action("CreateScheduledAudit")
CreateSecurityProfile = Action("CreateSecurityProfile")
CreateStream = Action("CreateStream")
CreateThing = Action("CreateThing")
CreateThingGroup = Action("CreateThingGroup")
CreateThingType = Action("CreateThingType")
CreateTopicRule = Action("CreateTopicRule")
CreateTopicRuleDestination = Action("CreateTopicRuleDestination")
DeleteAccountAuditConfiguration = Action("DeleteAccountAuditConfiguration")
DeleteAuditSuppression = Action("DeleteAuditSuppression")
DeleteAuthorizer = Action("DeleteAuthorizer")
DeleteBillingGroup = Action("DeleteBillingGroup")
DeleteCACertificate = Action("DeleteCACertificate")
DeleteCertificate = Action("DeleteCertificate")
DeleteCustomMetric = Action("DeleteCustomMetric")
DeleteDimension = Action("DeleteDimension")
DeleteDomainConfiguration = Action("DeleteDomainConfiguration")
DeleteDynamicThingGroup = Action("DeleteDynamicThingGroup")
DeleteFleetMetric = Action("DeleteFleetMetric")
DeleteJob = Action("DeleteJob")
DeleteJobExecution = Action("DeleteJobExecution")
DeleteJobTemplate = Action("DeleteJobTemplate")
DeleteMitigationAction = Action("DeleteMitigationAction")
DeleteOTAUpdate = Action("DeleteOTAUpdate")
DeleteOTAUpdateJob = Action("DeleteOTAUpdateJob")
DeletePolicy = Action("DeletePolicy")
DeletePolicyVersion = Action("DeletePolicyVersion")
DeleteProvisioningTemplate = Action("DeleteProvisioningTemplate")
DeleteProvisioningTemplateVersion = Action("DeleteProvisioningTemplateVersion")
DeleteRegistrationCode = Action("DeleteRegistrationCode")
DeleteRoleAlias = Action("DeleteRoleAlias")
DeleteScheduledAudit = Action("DeleteScheduledAudit")
DeleteSecurityProfile = Action("DeleteSecurityProfile")
DeleteStream = Action("DeleteStream")
DeleteThing = Action("DeleteThing")
DeleteThingGroup = Action("DeleteThingGroup")
DeleteThingShadow = Action("DeleteThingShadow")
DeleteThingType = Action("DeleteThingType")
DeleteTopicRule = Action("DeleteTopicRule")
DeleteTopicRuleDestination = Action("DeleteTopicRuleDestination")
DeleteV2LoggingLevel = Action("DeleteV2LoggingLevel")
DeprecateThingType = Action("DeprecateThingType")
DescribeAccountAuditConfiguration = Action("DescribeAccountAuditConfiguration")
DescribeAuditFinding = Action("DescribeAuditFinding")
DescribeAuditMitigationActionsTask = Action("DescribeAuditMitigationActionsTask")
DescribeAuditSuppression = Action("DescribeAuditSuppression")
DescribeAuditTask = Action("DescribeAuditTask")
DescribeAuthorizer = Action("DescribeAuthorizer")
DescribeBillingGroup = Action("DescribeBillingGroup")
DescribeCACertificate = Action("DescribeCACertificate")
DescribeCertificate = Action("DescribeCertificate")
DescribeCustomMetric = Action("DescribeCustomMetric")
DescribeDefaultAuthorizer = Action("DescribeDefaultAuthorizer")
DescribeDetectMitigationActionsTask = Action("DescribeDetectMitigationActionsTask")
DescribeDimension = Action("DescribeDimension")
DescribeDomainConfiguration = Action("DescribeDomainConfiguration")
DescribeEndpoint = Action("DescribeEndpoint")
DescribeEventConfigurations = Action("DescribeEventConfigurations")
DescribeFleetMetric = Action("DescribeFleetMetric")
DescribeIndex = Action("DescribeIndex")
DescribeJob = Action("DescribeJob")
DescribeJobExecution = Action("DescribeJobExecution")
DescribeJobTemplate = Action("DescribeJobTemplate")
DescribeManagedJobTemplate = Action("DescribeManagedJobTemplate")
DescribeMitigationAction = Action("DescribeMitigationAction")
DescribeProvisioningTemplate = Action("DescribeProvisioningTemplate")
DescribeProvisioningTemplateVersion = Action("DescribeProvisioningTemplateVersion")
DescribeRoleAlias = Action("DescribeRoleAlias")
DescribeScheduledAudit = Action("DescribeScheduledAudit")
DescribeSecurityProfile = Action("DescribeSecurityProfile")
DescribeStream = Action("DescribeStream")
DescribeThing = Action("DescribeThing")
DescribeThingGroup = Action("DescribeThingGroup")
DescribeThingRegistrationTask = Action("DescribeThingRegistrationTask")
DescribeThingType = Action("DescribeThingType")
DescribeTunnel = Action("DescribeTunnel")
DetachPolicy = Action("DetachPolicy")
DetachPrincipalPolicy = Action("DetachPrincipalPolicy")
DetachSecurityProfile = Action("DetachSecurityProfile")
DetachThingPrincipal = Action("DetachThingPrincipal")
DisableTopicRule = Action("DisableTopicRule")
EnableTopicRule = Action("EnableTopicRule")
GetBehaviorModelTrainingSummaries = Action("GetBehaviorModelTrainingSummaries")
GetBucketsAggregation = Action("GetBucketsAggregation")
GetCardinality = Action("GetCardinality")
GetEffectivePolicies = Action("GetEffectivePolicies")
GetIndexingConfiguration = Action("GetIndexingConfiguration")
GetJobDocument = Action("GetJobDocument")
GetLoggingOptions = Action("GetLoggingOptions")
GetOTAUpdate = Action("GetOTAUpdate")
GetOTAUpdateJob = Action("GetOTAUpdateJob")
GetPendingJobExecutions = Action("GetPendingJobExecutions")
GetPercentiles = Action("GetPercentiles")
GetPolicy = Action("GetPolicy")
GetPolicyVersion = Action("GetPolicyVersion")
GetRegistrationCode = Action("GetRegistrationCode")
GetRetainedMessage = Action("GetRetainedMessage")
GetStatistics = Action("GetStatistics")
GetThingShadow = Action("GetThingShadow")
GetTopicRule = Action("GetTopicRule")
GetTopicRuleDestination = Action("GetTopicRuleDestination")
GetV2LoggingOptions = Action("GetV2LoggingOptions")
ListActiveViolations = Action("ListActiveViolations")
ListAttachedPolicies = Action("ListAttachedPolicies")
ListAuditFindings = Action("ListAuditFindings")
ListAuditMitigationActionsExecutions = Action("ListAuditMitigationActionsExecutions")
ListAuditMitigationActionsTasks = Action("ListAuditMitigationActionsTasks")
ListAuditSuppressions = Action("ListAuditSuppressions")
ListAuditTasks = Action("ListAuditTasks")
ListAuthorizers = Action("ListAuthorizers")
ListBillingGroups = Action("ListBillingGroups")
ListCACertificates = Action("ListCACertificates")
ListCertificates = Action("ListCertificates")
ListCertificatesByCA = Action("ListCertificatesByCA")
ListCustomMetrics = Action("ListCustomMetrics")
ListDetectMitigationActionsExecutions = Action("ListDetectMitigationActionsExecutions")
ListDetectMitigationActionsTasks = Action("ListDetectMitigationActionsTasks")
ListDimensions = Action("ListDimensions")
ListDomainConfigurations = Action("ListDomainConfigurations")
ListFleetMetrics = Action("ListFleetMetrics")
ListIndices = Action("ListIndices")
ListJobExecutionsForJob = Action("ListJobExecutionsForJob")
ListJobExecutionsForThing = Action("ListJobExecutionsForThing")
ListJobTemplates = Action("ListJobTemplates")
ListJobs = Action("ListJobs")
ListManagedJobTemplates = Action("ListManagedJobTemplates")
ListMetricValues = Action("ListMetricValues")
ListMitigationActions = Action("ListMitigationActions")
ListNamedShadowsForThing = Action("ListNamedShadowsForThing")
ListOTAUpdateJobs = Action("ListOTAUpdateJobs")
ListOTAUpdates = Action("ListOTAUpdates")
ListOutgoingCertificates = Action("ListOutgoingCertificates")
ListPolicies = Action("ListPolicies")
ListPolicyPrincipals = Action("ListPolicyPrincipals")
ListPolicyVersions = Action("ListPolicyVersions")
ListPrincipalPolicies = Action("ListPrincipalPolicies")
ListPrincipalThings = Action("ListPrincipalThings")
ListProvisioningTemplateVersions = Action("ListProvisioningTemplateVersions")
ListProvisioningTemplates = Action("ListProvisioningTemplates")
ListRetainedMessages = Action("ListRetainedMessages")
ListRoleAliases = Action("ListRoleAliases")
ListScheduledAudits = Action("ListScheduledAudits")
ListSecurityProfiles = Action("ListSecurityProfiles")
ListSecurityProfilesForTarget = Action("ListSecurityProfilesForTarget")
ListStreams = Action("ListStreams")
ListTagsForResource = Action("ListTagsForResource")
ListTargetsForPolicy = Action("ListTargetsForPolicy")
ListTargetsForSecurityProfile = Action("ListTargetsForSecurityProfile")
ListThingGroups = Action("ListThingGroups")
ListThingGroupsForThing = Action("ListThingGroupsForThing")
ListThingPrincipals = Action("ListThingPrincipals")
ListThingRegistrationTaskReports = Action("ListThingRegistrationTaskReports")
ListThingRegistrationTasks = Action("ListThingRegistrationTasks")
ListThingTypes = Action("ListThingTypes")
ListThings = Action("ListThings")
ListThingsInBillingGroup = Action("ListThingsInBillingGroup")
ListThingsInThingGroup = Action("ListThingsInThingGroup")
ListTopicRuleDestinations = Action("ListTopicRuleDestinations")
ListTopicRules = Action("ListTopicRules")
ListTunnels = Action("ListTunnels")
ListV2LoggingLevels = Action("ListV2LoggingLevels")
ListViolationEvents = Action("ListViolationEvents")
OpenTunnel = Action("OpenTunnel")
Publish = Action("Publish")
PutVerificationStateOnViolation = Action("PutVerificationStateOnViolation")
Receive = Action("Receive")
RegisterCACertificate = Action("RegisterCACertificate")
RegisterCertificate = Action("RegisterCertificate")
RegisterCertificateWithoutCA = Action("RegisterCertificateWithoutCA")
RegisterThing = Action("RegisterThing")
RejectCertificateTransfer = Action("RejectCertificateTransfer")
RemoveThingFromBillingGroup = Action("RemoveThingFromBillingGroup")
RemoveThingFromThingGroup = Action("RemoveThingFromThingGroup")
ReplaceTopicRule = Action("ReplaceTopicRule")
RetainPublish = Action("RetainPublish")
RotateTunnelAccessToken = Action("RotateTunnelAccessToken")
SearchIndex = Action("SearchIndex")
SetDefaultAuthorizer = Action("SetDefaultAuthorizer")
SetDefaultPolicyVersion = Action("SetDefaultPolicyVersion")
SetLoggingOptions = Action("SetLoggingOptions")
SetV2LoggingLevel = Action("SetV2LoggingLevel")
SetV2LoggingOptions = Action("SetV2LoggingOptions")
StartAuditMitigationActionsTask = Action("StartAuditMitigationActionsTask")
StartDetectMitigationActionsTask = Action("StartDetectMitigationActionsTask")
StartNextPendingJobExecution = Action("StartNextPendingJobExecution")
StartOnDemandAuditTask = Action("StartOnDemandAuditTask")
StartThingRegistrationTask = Action("StartThingRegistrationTask")
StopThingRegistrationTask = Action("StopThingRegistrationTask")
Subscribe = Action("Subscribe")
TagResource = Action("TagResource")
TestAuthorization = Action("TestAuthorization")
TestInvokeAuthorizer = Action("TestInvokeAuthorizer")
TransferCertificate = Action("TransferCertificate")
UntagResource = Action("UntagResource")
UpdateAccountAuditConfiguration = Action("UpdateAccountAuditConfiguration")
UpdateAuditSuppression = Action("UpdateAuditSuppression")
UpdateAuthorizer = Action("UpdateAuthorizer")
UpdateBillingGroup = Action("UpdateBillingGroup")
UpdateCACertificate = Action("UpdateCACertificate")
UpdateCertificate = Action("UpdateCertificate")
UpdateCustomMetric = Action("UpdateCustomMetric")
UpdateDimension = Action("UpdateDimension")
UpdateDomainConfiguration = Action("UpdateDomainConfiguration")
UpdateDynamicThingGroup = Action("UpdateDynamicThingGroup")
UpdateEventConfigurations = Action("UpdateEventConfigurations")
UpdateFleetMetric = Action("UpdateFleetMetric")
UpdateIndexingConfiguration = Action("UpdateIndexingConfiguration")
UpdateJob = Action("UpdateJob")
UpdateJobExecution = Action("UpdateJobExecution")
UpdateMitigationAction = Action("UpdateMitigationAction")
UpdateProvisioningTemplate = Action("UpdateProvisioningTemplate")
UpdateRoleAlias = Action("UpdateRoleAlias")
UpdateScheduledAudit = Action("UpdateScheduledAudit")
UpdateSecurityProfile = Action("UpdateSecurityProfile")
UpdateStream = Action("UpdateStream")
UpdateThing = Action("UpdateThing")
UpdateThingGroup = Action("UpdateThingGroup")
UpdateThingGroupsForThing = Action("UpdateThingGroupsForThing")
UpdateThingShadow = Action("UpdateThingShadow")
UpdateTopicRuleDestination = Action("UpdateTopicRuleDestination")
ValidateSecurityProfileBehaviors = Action("ValidateSecurityProfileBehaviors")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Redshift"
prefix = "redshift"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptReservedNodeExchange = Action("AcceptReservedNodeExchange")
AddPartner = Action("AddPartner")
AssociateDataShareConsumer = Action("AssociateDataShareConsumer")
AuthorizeClusterSecurityGroupIngress = Action("AuthorizeClusterSecurityGroupIngress")
AuthorizeDataShare = Action("AuthorizeDataShare")
AuthorizeEndpointAccess = Action("AuthorizeEndpointAccess")
AuthorizeSnapshotAccess = Action("AuthorizeSnapshotAccess")
BatchDeleteClusterSnapshots = Action("BatchDeleteClusterSnapshots")
BatchModifyClusterSnapshots = Action("BatchModifyClusterSnapshots")
CancelQuery = Action("CancelQuery")
CancelQuerySession = Action("CancelQuerySession")
CancelResize = Action("CancelResize")
CopyClusterSnapshot = Action("CopyClusterSnapshot")
CreateAuthenticationProfile = Action("CreateAuthenticationProfile")
CreateCluster = Action("CreateCluster")
CreateClusterParameterGroup = Action("CreateClusterParameterGroup")
CreateClusterSecurityGroup = Action("CreateClusterSecurityGroup")
CreateClusterSnapshot = Action("CreateClusterSnapshot")
CreateClusterSubnetGroup = Action("CreateClusterSubnetGroup")
CreateClusterUser = Action("CreateClusterUser")
CreateEndpointAccess = Action("CreateEndpointAccess")
CreateEventSubscription = Action("CreateEventSubscription")
CreateHsmClientCertificate = Action("CreateHsmClientCertificate")
CreateHsmConfiguration = Action("CreateHsmConfiguration")
CreateSavedQuery = Action("CreateSavedQuery")
CreateScheduledAction = Action("CreateScheduledAction")
CreateSnapshotCopyGrant = Action("CreateSnapshotCopyGrant")
CreateSnapshotSchedule = Action("CreateSnapshotSchedule")
CreateTags = Action("CreateTags")
CreateUsageLimit = Action("CreateUsageLimit")
DeauthorizeDataShare = Action("DeauthorizeDataShare")
DeleteAuthenticationProfile = Action("DeleteAuthenticationProfile")
DeleteCluster = Action("DeleteCluster")
DeleteClusterParameterGroup = Action("DeleteClusterParameterGroup")
DeleteClusterSecurityGroup = Action("DeleteClusterSecurityGroup")
DeleteClusterSnapshot = Action("DeleteClusterSnapshot")
DeleteClusterSubnetGroup = Action("DeleteClusterSubnetGroup")
DeleteEndpointAccess = Action("DeleteEndpointAccess")
DeleteEventSubscription = Action("DeleteEventSubscription")
DeleteHsmClientCertificate = Action("DeleteHsmClientCertificate")
DeleteHsmConfiguration = Action("DeleteHsmConfiguration")
DeletePartner = Action("DeletePartner")
DeleteSavedQueries = Action("DeleteSavedQueries")
DeleteScheduledAction = Action("DeleteScheduledAction")
DeleteSnapshotCopyGrant = Action("DeleteSnapshotCopyGrant")
DeleteSnapshotSchedule = Action("DeleteSnapshotSchedule")
DeleteTags = Action("DeleteTags")
DeleteUsageLimit = Action("DeleteUsageLimit")
DescribeAccountAttributes = Action("DescribeAccountAttributes")
DescribeAuthenticationProfiles = Action("DescribeAuthenticationProfiles")
DescribeClusterDbRevisions = Action("DescribeClusterDbRevisions")
DescribeClusterParameterGroups = Action("DescribeClusterParameterGroups")
DescribeClusterParameters = Action("DescribeClusterParameters")
DescribeClusterSecurityGroups = Action("DescribeClusterSecurityGroups")
DescribeClusterSnapshots = Action("DescribeClusterSnapshots")
DescribeClusterSubnetGroups = Action("DescribeClusterSubnetGroups")
DescribeClusterTracks = Action("DescribeClusterTracks")
DescribeClusterVersions = Action("DescribeClusterVersions")
DescribeClusters = Action("DescribeClusters")
DescribeDataShares = Action("DescribeDataShares")
DescribeDataSharesForConsumer = Action("DescribeDataSharesForConsumer")
DescribeDataSharesForProducer = Action("DescribeDataSharesForProducer")
DescribeDefaultClusterParameters = Action("DescribeDefaultClusterParameters")
DescribeEndpointAccess = Action("DescribeEndpointAccess")
DescribeEndpointAuthorization = Action("DescribeEndpointAuthorization")
DescribeEventCategories = Action("DescribeEventCategories")
DescribeEventSubscriptions = Action("DescribeEventSubscriptions")
DescribeEvents = Action("DescribeEvents")
DescribeHsmClientCertificates = Action("DescribeHsmClientCertificates")
DescribeHsmConfigurations = Action("DescribeHsmConfigurations")
DescribeLoggingStatus = Action("DescribeLoggingStatus")
DescribeNodeConfigurationOptions = Action("DescribeNodeConfigurationOptions")
DescribeOrderableClusterOptions = Action("DescribeOrderableClusterOptions")
DescribePartners = Action("DescribePartners")
DescribeQuery = Action("DescribeQuery")
DescribeReservedNodeExchangeStatus = Action("DescribeReservedNodeExchangeStatus")
DescribeReservedNodeOfferings = Action("DescribeReservedNodeOfferings")
DescribeReservedNodes = Action("DescribeReservedNodes")
DescribeResize = Action("DescribeResize")
DescribeSavedQueries = Action("DescribeSavedQueries")
DescribeScheduledActions = Action("DescribeScheduledActions")
DescribeSnapshotCopyGrants = Action("DescribeSnapshotCopyGrants")
DescribeSnapshotSchedules = Action("DescribeSnapshotSchedules")
DescribeStorage = Action("DescribeStorage")
DescribeTable = Action("DescribeTable")
DescribeTableRestoreStatus = Action("DescribeTableRestoreStatus")
DescribeTags = Action("DescribeTags")
DescribeUsageLimits = Action("DescribeUsageLimits")
DisableLogging = Action("DisableLogging")
DisableSnapshotCopy = Action("DisableSnapshotCopy")
DisassociateDataShareConsumer = Action("DisassociateDataShareConsumer")
EnableLogging = Action("EnableLogging")
EnableSnapshotCopy = Action("EnableSnapshotCopy")
ExecuteQuery = Action("ExecuteQuery")
FetchResults = Action("FetchResults")
GetClusterCredentials = Action("GetClusterCredentials")
GetReservedNodeExchangeConfigurationOptions = Action(
    "GetReservedNodeExchangeConfigurationOptions"
)
GetReservedNodeExchangeOfferings = Action("GetReservedNodeExchangeOfferings")
JoinGroup = Action("JoinGroup")
ListDatabases = Action("ListDatabases")
ListSavedQueries = Action("ListSavedQueries")
ListSchemas = Action("ListSchemas")
ListTables = Action("ListTables")
ModifyAquaConfiguration = Action("ModifyAquaConfiguration")
ModifyAuthenticationProfile = Action("ModifyAuthenticationProfile")
ModifyCluster = Action("ModifyCluster")
ModifyClusterDbRevision = Action("ModifyClusterDbRevision")
ModifyClusterIamRoles = Action("ModifyClusterIamRoles")
ModifyClusterMaintenance = Action("ModifyClusterMaintenance")
ModifyClusterParameterGroup = Action("ModifyClusterParameterGroup")
ModifyClusterSnapshot = Action("ModifyClusterSnapshot")
ModifyClusterSnapshotSchedule = Action("ModifyClusterSnapshotSchedule")
ModifyClusterSubnetGroup = Action("ModifyClusterSubnetGroup")
ModifyEndpointAccess = Action("ModifyEndpointAccess")
ModifyEventSubscription = Action("ModifyEventSubscription")
ModifySavedQuery = Action("ModifySavedQuery")
ModifyScheduledAction = Action("ModifyScheduledAction")
ModifySnapshotCopyRetentionPeriod = Action("ModifySnapshotCopyRetentionPeriod")
ModifySnapshotSchedule = Action("ModifySnapshotSchedule")
ModifyUsageLimit = Action("ModifyUsageLimit")
PauseCluster = Action("PauseCluster")
PurchaseReservedNodeOffering = Action("PurchaseReservedNodeOffering")
RebootCluster = Action("RebootCluster")
RejectDataShare = Action("RejectDataShare")
ResetClusterParameterGroup = Action("ResetClusterParameterGroup")
ResizeCluster = Action("ResizeCluster")
RestoreFromClusterSnapshot = Action("RestoreFromClusterSnapshot")
RestoreTableFromClusterSnapshot = Action("RestoreTableFromClusterSnapshot")
ResumeCluster = Action("ResumeCluster")
RevokeClusterSecurityGroupIngress = Action("RevokeClusterSecurityGroupIngress")
RevokeEndpointAccess = Action("RevokeEndpointAccess")
RevokeSnapshotAccess = Action("RevokeSnapshotAccess")
RotateEncryptionKey = Action("RotateEncryptionKey")
UpdatePartnerStatus = Action("UpdatePartnerStatus")
ViewQueriesFromConsole = Action("ViewQueriesFromConsole")
ViewQueriesInConsole = Action("ViewQueriesInConsole")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Billing and Cost Management"
prefix = "aws-portal"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ModifyAccount = Action("ModifyAccount")
ModifyBilling = Action("ModifyBilling")
ModifyPaymentMethods = Action("ModifyPaymentMethods")
ViewAccount = Action("ViewAccount")
ViewBilling = Action("ViewBilling")
ViewPaymentMethods = Action("ViewPaymentMethods")
ViewUsage = Action("ViewUsage")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS OpsWorks"
prefix = "opsworks"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssignInstance = Action("AssignInstance")
AssignVolume = Action("AssignVolume")
AssociateElasticIp = Action("AssociateElasticIp")
AttachElasticLoadBalancer = Action("AttachElasticLoadBalancer")
CloneStack = Action("CloneStack")
CreateApp = Action("CreateApp")
CreateDeployment = Action("CreateDeployment")
CreateInstance = Action("CreateInstance")
CreateLayer = Action("CreateLayer")
CreateStack = Action("CreateStack")
CreateUserProfile = Action("CreateUserProfile")
DeleteApp = Action("DeleteApp")
DeleteInstance = Action("DeleteInstance")
DeleteLayer = Action("DeleteLayer")
DeleteStack = Action("DeleteStack")
DeleteUserProfile = Action("DeleteUserProfile")
DeregisterEcsCluster = Action("DeregisterEcsCluster")
DeregisterElasticIp = Action("DeregisterElasticIp")
DeregisterInstance = Action("DeregisterInstance")
DeregisterRdsDbInstance = Action("DeregisterRdsDbInstance")
DeregisterVolume = Action("DeregisterVolume")
DescribeAgentVersions = Action("DescribeAgentVersions")
DescribeApps = Action("DescribeApps")
DescribeCommands = Action("DescribeCommands")
DescribeDeployments = Action("DescribeDeployments")
DescribeEcsClusters = Action("DescribeEcsClusters")
DescribeElasticIps = Action("DescribeElasticIps")
DescribeElasticLoadBalancers = Action("DescribeElasticLoadBalancers")
DescribeInstances = Action("DescribeInstances")
DescribeLayers = Action("DescribeLayers")
DescribeLoadBasedAutoScaling = Action("DescribeLoadBasedAutoScaling")
DescribeMyUserProfile = Action("DescribeMyUserProfile")
DescribeOperatingSystems = Action("DescribeOperatingSystems")
DescribePermissions = Action("DescribePermissions")
DescribeRaidArrays = Action("DescribeRaidArrays")
DescribeRdsDbInstances = Action("DescribeRdsDbInstances")
DescribeServiceErrors = Action("DescribeServiceErrors")
DescribeStackProvisioningParameters = Action("DescribeStackProvisioningParameters")
DescribeStackSummary = Action("DescribeStackSummary")
DescribeStacks = Action("DescribeStacks")
DescribeTimeBasedAutoScaling = Action("DescribeTimeBasedAutoScaling")
DescribeUserProfiles = Action("DescribeUserProfiles")
DescribeVolumes = Action("DescribeVolumes")
DetachElasticLoadBalancer = Action("DetachElasticLoadBalancer")
DisassociateElasticIp = Action("DisassociateElasticIp")
GetHostnameSuggestion = Action("GetHostnameSuggestion")
GrantAccess = Action("GrantAccess")
ListTags = Action("ListTags")
RebootInstance = Action("RebootInstance")
RegisterEcsCluster = Action("RegisterEcsCluster")
RegisterElasticIp = Action("RegisterElasticIp")
RegisterInstance = Action("RegisterInstance")
RegisterRdsDbInstance = Action("RegisterRdsDbInstance")
RegisterVolume = Action("RegisterVolume")
SetLoadBasedAutoScaling = Action("SetLoadBasedAutoScaling")
SetPermission = Action("SetPermission")
SetTimeBasedAutoScaling = Action("SetTimeBasedAutoScaling")
StartInstance = Action("StartInstance")
StartStack = Action("StartStack")
StopInstance = Action("StopInstance")
StopStack = Action("StopStack")
TagResource = Action("TagResource")
UnassignInstance = Action("UnassignInstance")
UnassignVolume = Action("UnassignVolume")
UntagResource = Action("UntagResource")
UpdateApp = Action("UpdateApp")
UpdateElasticIp = Action("UpdateElasticIp")
UpdateInstance = Action("UpdateInstance")
UpdateLayer = Action("UpdateLayer")
UpdateMyUserProfile = Action("UpdateMyUserProfile")
UpdateRdsDbInstance = Action("UpdateRdsDbInstance")
UpdateStack = Action("UpdateStack")
UpdateUserProfile = Action("UpdateUserProfile")
UpdateVolume = Action("UpdateVolume")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodeStar Notifications"
prefix = "codestar-notifications"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateNotificationRule = Action("CreateNotificationRule")
DeleteNotificationRule = Action("DeleteNotificationRule")
DeleteTarget = Action("DeleteTarget")
DescribeNotificationRule = Action("DescribeNotificationRule")
ListEventTypes = Action("ListEventTypes")
ListNotificationRules = Action("ListNotificationRules")
ListTagsForResource = Action("ListTagsForResource")
ListTargets = Action("ListTargets")
Subscribe = Action("Subscribe")
TagResource = Action("TagResource")
Unsubscribe = Action("Unsubscribe")
UntagResource = Action("UntagResource")
UpdateNotificationRule = Action("UpdateNotificationRule")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon CloudWatch Evidently"
prefix = "evidently"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchEvaluateFeature = Action("BatchEvaluateFeature")
CreateExperiment = Action("CreateExperiment")
CreateFeature = Action("CreateFeature")
CreateLaunch = Action("CreateLaunch")
CreateProject = Action("CreateProject")
DeleteExperiment = Action("DeleteExperiment")
DeleteFeature = Action("DeleteFeature")
DeleteLaunch = Action("DeleteLaunch")
DeleteProject = Action("DeleteProject")
EvaluateFeature = Action("EvaluateFeature")
GetExperiment = Action("GetExperiment")
GetExperimentResults = Action("GetExperimentResults")
GetFeature = Action("GetFeature")
GetLaunch = Action("GetLaunch")
GetProject = Action("GetProject")
ListExperiments = Action("ListExperiments")
ListFeatures = Action("ListFeatures")
ListLaunches = Action("ListLaunches")
ListProjects = Action("ListProjects")
ListTagsForResource = Action("ListTagsForResource")
PutProjectEvents = Action("PutProjectEvents")
StartExperiment = Action("StartExperiment")
StartLaunch = Action("StartLaunch")
StopExperiment = Action("StopExperiment")
StopLaunch = Action("StopLaunch")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateExperiment = Action("UpdateExperiment")
UpdateFeature = Action("UpdateFeature")
UpdateLaunch = Action("UpdateLaunch")
UpdateProject = Action("UpdateProject")
UpdateProjectDataDelivery = Action("UpdateProjectDataDelivery")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Glue DataBrew"
prefix = "databrew"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchDeleteRecipeVersion = Action("BatchDeleteRecipeVersion")
CreateDataset = Action("CreateDataset")
CreateProfileJob = Action("CreateProfileJob")
CreateProject = Action("CreateProject")
CreateRecipe = Action("CreateRecipe")
CreateRecipeJob = Action("CreateRecipeJob")
CreateRuleset = Action("CreateRuleset")
CreateSchedule = Action("CreateSchedule")
DeleteDataset = Action("DeleteDataset")
DeleteJob = Action("DeleteJob")
DeleteProject = Action("DeleteProject")
DeleteRecipeVersion = Action("DeleteRecipeVersion")
DeleteRuleset = Action("DeleteRuleset")
DeleteSchedule = Action("DeleteSchedule")
DescribeDataset = Action("DescribeDataset")
DescribeJob = Action("DescribeJob")
DescribeJobRun = Action("DescribeJobRun")
DescribeProject = Action("DescribeProject")
DescribeRecipe = Action("DescribeRecipe")
DescribeRuleset = Action("DescribeRuleset")
DescribeSchedule = Action("DescribeSchedule")
ListDatasets = Action("ListDatasets")
ListJobRuns = Action("ListJobRuns")
ListJobs = Action("ListJobs")
ListProjects = Action("ListProjects")
ListRecipeVersions = Action("ListRecipeVersions")
ListRecipes = Action("ListRecipes")
ListRulesets = Action("ListRulesets")
ListSchedules = Action("ListSchedules")
ListTagsForResource = Action("ListTagsForResource")
PublishRecipe = Action("PublishRecipe")
SendProjectSessionAction = Action("SendProjectSessionAction")
StartJobRun = Action("StartJobRun")
StartProjectSession = Action("StartProjectSession")
StopJobRun = Action("StopJobRun")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDataset = Action("UpdateDataset")
UpdateProfileJob = Action("UpdateProfileJob")
UpdateProject = Action("UpdateProject")
UpdateRecipe = Action("UpdateRecipe")
UpdateRecipeJob = Action("UpdateRecipeJob")
UpdateRuleset = Action("UpdateRuleset")
UpdateSchedule = Action("UpdateSchedule")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Interactive Video Service Chat"
prefix = "ivschat"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateChatToken = Action("CreateChatToken")
CreateRoom = Action("CreateRoom")
DeleteMessage = Action("DeleteMessage")
DeleteRoom = Action("DeleteRoom")
DisconnectUser = Action("DisconnectUser")
GetRoom = Action("GetRoom")
ListRooms = Action("ListRooms")
ListTagsForResource = Action("ListTagsForResource")
SendEvent = Action("SendEvent")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateRoom = Action("UpdateRoom")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Simple Workflow Service"
prefix = "swf"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelTimer = Action("CancelTimer")
CancelWorkflowExecution = Action("CancelWorkflowExecution")
CompleteWorkflowExecution = Action("CompleteWorkflowExecution")
ContinueAsNewWorkflowExecution = Action("ContinueAsNewWorkflowExecution")
CountClosedWorkflowExecutions = Action("CountClosedWorkflowExecutions")
CountOpenWorkflowExecutions = Action("CountOpenWorkflowExecutions")
CountPendingActivityTasks = Action("CountPendingActivityTasks")
CountPendingDecisionTasks = Action("CountPendingDecisionTasks")
DeprecateActivityType = Action("DeprecateActivityType")
DeprecateDomain = Action("DeprecateDomain")
DeprecateWorkflowType = Action("DeprecateWorkflowType")
DescribeActivityType = Action("DescribeActivityType")
DescribeDomain = Action("DescribeDomain")
DescribeWorkflowExecution = Action("DescribeWorkflowExecution")
DescribeWorkflowType = Action("DescribeWorkflowType")
FailWorkflowExecution = Action("FailWorkflowExecution")
GetWorkflowExecutionHistory = Action("GetWorkflowExecutionHistory")
ListActivityTypes = Action("ListActivityTypes")
ListClosedWorkflowExecutions = Action("ListClosedWorkflowExecutions")
ListDomains = Action("ListDomains")
ListOpenWorkflowExecutions = Action("ListOpenWorkflowExecutions")
ListTagsForResource = Action("ListTagsForResource")
ListWorkflowTypes = Action("ListWorkflowTypes")
PollForActivityTask = Action("PollForActivityTask")
PollForDecisionTask = Action("PollForDecisionTask")
RecordActivityTaskHeartbeat = Action("RecordActivityTaskHeartbeat")
RecordMarker = Action("RecordMarker")
RegisterActivityType = Action("RegisterActivityType")
RegisterDomain = Action("RegisterDomain")
RegisterWorkflowType = Action("RegisterWorkflowType")
RequestCancelActivityTask = Action("RequestCancelActivityTask")
RequestCancelExternalWorkflowExecution = Action(
    "RequestCancelExternalWorkflowExecution"
)
RequestCancelWorkflowExecution = Action("RequestCancelWorkflowExecution")
RespondActivityTaskCanceled = Action("RespondActivityTaskCanceled")
RespondActivityTaskCompleted = Action("RespondActivityTaskCompleted")
RespondActivityTaskFailed = Action("RespondActivityTaskFailed")
RespondDecisionTaskCompleted = Action("RespondDecisionTaskCompleted")
ScheduleActivityTask = Action("ScheduleActivityTask")
SignalExternalWorkflowExecution = Action("SignalExternalWorkflowExecution")
SignalWorkflowExecution = Action("SignalWorkflowExecution")
StartChildWorkflowExecution = Action("StartChildWorkflowExecution")
StartTimer = Action("StartTimer")
StartWorkflowExecution = Action("StartWorkflowExecution")
TagResource = Action("TagResource")
TerminateWorkflowExecution = Action("TerminateWorkflowExecution")
UndeprecateActivityType = Action("UndeprecateActivityType")
UndeprecateDomain = Action("UndeprecateDomain")
UndeprecateWorkflowType = Action("UndeprecateWorkflowType")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Mainframe Modernization Service"
prefix = "m2"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelBatchJobExecution = Action("CancelBatchJobExecution")
CreateApplication = Action("CreateApplication")
CreateDataSetImportTask = Action("CreateDataSetImportTask")
CreateDeployment = Action("CreateDeployment")
CreateEnvironment = Action("CreateEnvironment")
DeleteApplication = Action("DeleteApplication")
DeleteApplicationFromEnvironment = Action("DeleteApplicationFromEnvironment")
DeleteEnvironment = Action("DeleteEnvironment")
GetApplication = Action("GetApplication")
GetApplicationVersion = Action("GetApplicationVersion")
GetBatchJobExecution = Action("GetBatchJobExecution")
GetDataSetDetails = Action("GetDataSetDetails")
GetDataSetImportTask = Action("GetDataSetImportTask")
GetDeployment = Action("GetDeployment")
GetEnvironment = Action("GetEnvironment")
ListApplicationVersions = Action("ListApplicationVersions")
ListApplications = Action("ListApplications")
ListBatchJobDefinitions = Action("ListBatchJobDefinitions")
ListBatchJobExecutions = Action("ListBatchJobExecutions")
ListDataSetImportHistory = Action("ListDataSetImportHistory")
ListDataSets = Action("ListDataSets")
ListDeployments = Action("ListDeployments")
ListEngineVersions = Action("ListEngineVersions")
ListEnvironments = Action("ListEnvironments")
ListTagsForResource = Action("ListTagsForResource")
StartApplication = Action("StartApplication")
StartBatchJob = Action("StartBatchJob")
StopApplication = Action("StopApplication")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApplication = Action("UpdateApplication")
UpdateEnvironment = Action("UpdateEnvironment")
